@@ -67,15 +67,13 @@ def print_record(line: str, console: Console, config: Config) -> None:
     try:
         record = Record.from_line(json.loads(line), config=config)
     except Exception:  # noqa: PIE786
-        console.print(line)  # Print the unmodified line
+        console.print(line.rstrip(), markup=False)  # Print the unmodified line
         return
 
     if (_this_level := get_level(name=record.level)) == logging.NOTSET and record.level:
         record.data['_level_name'] = record.level
 
     printer_kwargs = {
-        **record.data,
-        # Ensure that there is no repeat keyword arguments
         'message': record.message,
         'is_header': False,
         '_this_level': _this_level,
@@ -85,4 +83,9 @@ def print_record(line: str, console: Console, config: Config) -> None:
         '_keys_on_own_line': config.keys.on_own_line,
         'timestamp': record.timestamp,
     }
-    rich_printer(**printer_kwargs)
+    keys = set(printer_kwargs)
+    rich_printer(
+        **printer_kwargs,
+        # Ensure that there is no repeat keyword arguments
+        **{f'_{key}' if key in keys else key: value for key, value in record.data.items()},
+    )
